@@ -53,6 +53,7 @@ public:
     virtual ~UnlockApp();
 
     void setTesting(bool enable);
+    void setTheme(const QString &theme);
     void setImmediateLock(bool immediateLock);
     void lockImmediately();
     void setGraceTime(int milliseconds);
@@ -61,6 +62,8 @@ public:
 
     void osdProgress(const QString &icon, int percent, const QString &additionalText);
     void osdText(const QString &icon, const QString &additionalText);
+    void updateCanSuspend(bool set);
+    void updateCanHibernate(bool set);
 
 public Q_SLOTS:
     void desktopResized();
@@ -81,6 +84,7 @@ private:
     void initializeWayland();
     void shareEvent(QEvent *e, KQuickAddons::QuickViewSharedEngine *from);
 
+    QString m_packageName;
     QUrl m_mainQmlPath;
     QList<KQuickAddons::QuickViewSharedEngine*> m_views;
     QTimer *m_resetRequestIgnoreTimer;
@@ -94,6 +98,9 @@ private:
     int m_graceTime;
     bool m_noLock;
 
+    bool m_canSuspend = false;
+    bool m_canHibernate = false;
+
     KWayland::Client::ConnectionThread *m_ksldConnection = nullptr;
     KWayland::Client::Registry *m_ksldRegistry = nullptr;
     QThread *m_ksldConnectionThread = nullptr;
